import QtQuick 2.5
import Fly.Components 1.0
import Fly.Widgets.Music 1.0

Rectangle {
    color: styles.colors.black3
    opacity: mprisControl.available ? 1.0 : 0.6

    //property string iconPath: "file:///home/user/projects/fly-music/app/icons/";
    property string iconPath: "file:///usr/share/rusbitech/fly-music/icons/";

    MouseArea {
        anchors.fill: parent

        onClicked: root.startDetachedProcess("fly-music", ["--raise"]);

        Image {
            id: coverImage
            anchors { left: parent.left; top: parent.top; bottom: parent.bottom; }
            width: parent.height
            source: (mprisControl.state !== MPRISControl.Stopped && mprisControl.coverUrl.length > 0) ?
                        mprisControl.coverUrl :
                        iconPath + "empty-cover.svg"

            sourceSize: Qt.size(2*width, 0)
            asynchronous: true
        }

        Item {
            id: description
            anchors { top: parent.top; bottom: parent.verticalCenter; left: coverImage.right; right: parent.right }

            Column {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                anchors.margins: 15 * dpiRatio
                visible: mprisControl.state !== MPRISControl.Stopped
                spacing: 15 * dpiRatio

                FlyLabel {
                    id: firstTitle
                    width: parent.width
                    text: mprisControl.firstLine
                    color: styles.colors.white
                    elide: Text.ElideRight
                    fontSizeMode: Text.FixedSize
                }

                FlyLabel {
                    id: secondTitle
                    width: parent.width
                    text: mprisControl.secondLine
                    color: styles.colors.white
                    elide: Text.ElideRight
                    fontSizeMode: Text.FixedSize
                }
            }
        }

        Item {
            id: positionbar
            anchors {
                margins: 10 * dpiRatio;
                left: coverImage.right;
                right: parent.right;
                top: parent.verticalCenter;
            }
            height: parent.height / 8
            property alias color: highlight.color
            property int position: 0
            property int duration: mprisControl.length
            signal seekRequest(int pos)

            Rectangle {
                id: backGround
                anchors { fill: parent }
                color: styles.colors.gray

                Rectangle {
                    id: highlight
                    width: positionbar.duration > 0 ? (parent.width * positionbar.position / positionbar.duration) : 0

                    anchors { left: parent.left; top: parent.top; bottom: parent.bottom }
                    color: styles.colors.white
                }


                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if(positionbar.duration > 0)
                            positionbar.seekRequest(mouse.x  * positionbar.duration / width);
                    }

                    onMouseXChanged: {
                        if(containsPress && positionbar.duration > 0)
                            positionbar.seekRequest(mouse.x  * positionbar.duration / width);
                    }
                }
            }

            onSeekRequest: mprisControl.seek(pos);

            Connections {
                target: mprisControl
                onSeeked: positionbar.position = pos;
                onStateChanged: {
                    if(mprisControl.state === MPRISControl.Stopped)
                        positionbar.position = 0;
                }
            }

            Timer {
                id: timer
                interval: 500
                repeat: true
                running: mprisControl.state === MPRISControl.Playing
                onTriggered: positionbar.position += 500000
            }
        }


        Row {
            anchors { horizontalCenter: positionbar.horizontalCenter;  top: positionbar.bottom; bottom: parent.bottom; margins: 20 * dpiRatio }

            FlyMenuButton {
                id: previousButton
                image.imagePath: iconPath + "previous.svg"
                onClicked: mprisControl.previous()
            }

            FlyMenuButton {
                id: stopButton
                image.imagePath: iconPath + "stop.svg"
                onClicked: mprisControl.stop()
            }


            FlyMenuButton {
                id: nextButton
                image.imagePath: iconPath + "next.svg"
                onClicked: mprisControl.next()
            }

            FlyMenuButton {
                id: playPauseButton
                image.imagePath:  iconPath + (mprisControl.state === MPRISControl.Playing ? "pause.svg" : "play.svg")
                onClicked: mprisControl.playPause()
            }
        }
    }
}
